==> dorsia-0.2.5.tgz: package/src/opentable.js <==
"use strict";

const Nightmare = require('../node_modules/nightmare');
const moment = require("../node_modules/moment");
const Utility = require("./utility");
const async = require("../node_modules/async");
const chalk = require("../node_modules/chalk");

module.exports = {
  cityList: Utility.cityList,

  createRezObjs: (opentableIdArray, city, date, party, time) => {
    return Utility.createRezObjs(opentableIdArray, city, date, party, time);
  },

  queryEater: (city, debug, done) => {

    let url = Utility.getCityUrl(city);
    debug = (debug === true);

    new Nightmare({ show: debug, waitTimeout: 5000 })


    .goto(url)
    .inject('js', __dirname + '/../node_modules/jquery/dist/jquery.min.js')
    .wait('.l-map__points-content')

    .evaluate( function(city) {

      let restaurantInfoJSON = [];

      let restaurants = $('.m-map__item-card');

      for (let i = 0; i < restaurants.length; i++) {

        let $card = $(restaurants[i]);
        let name = $card.attr('data-name');
        let location = $card.attr('data-coordinates');
        let description = $($card.find('p')[0]).text();
        let webAndPhone = $card.find('div.m-map__item-website > div');
        let opentable = $card.find('.m-chorus-opentable-button');
        let isReservable = false;
        let phone = "no phone";
        let website = "no website provided";
        let opentableId = "";
        let reserveUrl = ""
        let reserveUrlMobile = ""
        let address = ""

        let address1 = $card.find('div.m-map__item-address > div:nth-child(1)');
        let address2 = $card.find('div.m-map__item-address > div:nth-child(2)');

        if (address1.length > 0) {
          address += address1[0].innerHTML.trim();
        }

        if (address2.length > 0) {
          address += '\n' + address2[0].innerHTML.trim();
        }

        if (webAndPhone.length > 0) {
          website = webAndPhone.find('a').attr('href');
        }

        if (webAndPhone.length > 1) {
          phone = webAndPhone[1].innerHTML.trim();
        }

        if (opentable.length > 0) {
          opentableId = opentable.attr('data-opentable-id');
          reserveUrl = `http://www.opentable.com/single.aspx?rid=${opentableId}`;
          reserveUrlMobile = `http://mobile.opentable.com/opentable/?restId=${opentableId}`;
          isReservable = true;
        }


        let restaurant = {
          name: name,
          isReservable: isReservable,
          opentableId: opentableId,
          reserveUrl: reserveUrl,
          reserveUrlMobile: reserveUrlMobile,
          location: location,
          description: description,
          address: address,
          phone: phone,
          website: website,
          city: city
        };

        restaurantInfoJSON.push(restaurant)

      }

      return restaurantInfoJSON

    }, city)

    .run(function (err, result) {
      if (err) {
        done({message:"error pulling: " + city, success: false, data: result, error: err});
        console.log(chalk.red("error pulling: ") + city)
      } else {
        done({message:"success pulling: " + city, success: true, data: result, error: err});
        console.log(chalk.orange("success pulling: ") + city)
      }
    })

    .end();
  },

  queryTables: (opts,debug,done) => {
    let url = `http://www.opentable.com/single.aspx?rid=${opts.restId}?p=${opts.party}&d=${opts.date}%20${opts.time}`
    debug = (debug === true);
    new Nightmare({ show: debug, waitTimeout: 5000 })

      .goto(url)
      .inject('js', __dirname + '/../node_modules/jquery/dist/jquery.min.js')
      .wait(2000)
      .wait('.dtp-picker-button')
      .click('.dtp-picker-button')
      .wait(2000)
      .wait('.dtp-result-text')
      .evaluate( function() {

        let times = $('#dtp-results > div > ul > li > a');
        let avalibleTimes = [];
        let name = $('h1.page-header-title')[0].innerHTML;

        for (let i = 0; i < times.length; i++) {

          let datetime = times[i].getAttribute('data-datetime');

          if (datetime) {
            avalibleTimes.push( datetime.split(' ')[1] );
          }

        }

        let reservation = {
          name: name,
          tables: avalibleTimes
        }

        return reservation;

      })

      .run(function (err, result) {
        if (err) {
          done(this,{message:"error pulling times for: " + opts.restId, success: false, optId: opts.restId, data: result, error: err});
          console.log(chalk.yellow("error polling: ") + opts.restId)
          console.log(chalk.red("error: ") + err)
        } else {
          result['requestedDatetime'] = opts.time;
          done(this,{message:"success for: " + opts.restId, success: true, optId: opts.restId, data: result, error: err});
          console.log(chalk.blue("success polling: ") + opts.restId)
        }
      })
      .end()
  },

  openTables: function (rezObjs, debug, concurrentJobs, done) {
    var _this = this;
    var callbacks = [];
    async.eachLimit(rezObjs, concurrentJobs, function(rezObj,callback) {
      _this.queryTables(rezObj, debug, function(nm, result) {
        nm.end();
        callbacks.push(result);
        callback();
      });
    }, function(err) {
      console.log(err);
      console.log(callbacks);
      done(err, callbacks);
    })
  },

  eaterAll: function (debug,concurrentJobs,done) {
    var _this = this;
    var callbacks = [];
    let cites = Object.keys(Utility.cityList);
    async.eachLimit(cites, concurrentJobs, function(city,callback) {
      _this.queryEater(city, debug, function(result) {
        callbacks.push(result);
        callback();
      });
    }, function(err) {
      done(err, callbacks);
    })
  },

  reserveTable: function (opentableId, date, time, partySize, email, firstName, lastName, phone, callback) {
    const _this = this;
    //clean dates
    const dateString = Utility.getDateTimeString(date,time);
    let url = `http://www.opentable.com/single.aspx?rid=${opentableId}?p=${partySize}&d=${date}%20${time}`

    new Nightmare({ show: false, waitTimeout: 2000 })

      .goto(url)
      .inject('js', __dirname + '/../node_modules/jquery/dist/jquery.min.js')
      .click('.dtp-picker-button')
      .wait('.dtp-result-text')
      .wait(2000)
      .evaluate(function (dateString) {

        let times = $('#dtp-results > div > ul > li > a');
        let avalibleTimes = [];
        let timeIndex = null;

        for (let i = 0; i < times.length; i++) {

          let datetime = times[i].getAttribute('data-datetime');

          if (datetime && datetime === dateString) {
            timeIndex = i + 1;
          }

          if (datetime) {
            avalibleTimes.push( datetime.split(' ')[1] );
          }

        }

        const result = {
          times: avalibleTimes,
          index: timeIndex
        }

        return result

      }, dateString)

      .run( (err, result) => {

        if (err) {
          return console.log(err);
        } else {
          if (result.index) {
            _this.bookTable(opentableId, date, time, partySize,result.index, email, firstName, lastName, phone, (err, result) => {
                return callback(err,result);
            });

          } else {
            console.log();
            callback(null, { success: false, message:{ message: "No reservations availible at that time.", avalibleTimes: result.times } })
          }
        }
      })
      .end();
  },
  bookTable: function(opentableId, date, time, partySize, timeIndex, email, firstName, lastName, phone, callback) {

    const bookingSelector = `#dtp-results > div > ul > li:nth-child(${timeIndex}) > a`;
    const dateString = Utility.getDateTimeString(date,time);

    let url = `http://www.opentable.com/single.aspx?rid=${opentableId}?p=${partySize}&d=${date}%20${time}`

    new Nightmare({ show: false, waitTimeout: 2000})
      .goto(url)
      .inject('js', __dirname + '/../node_modules/jquery/dist/jquery.min.js')
      .click('.dtp-picker-button')
      .wait('.dtp-result-text')
      .click(bookingSelector)
      .type('#email', email)
      .type('#firstName', firstName)
      .type('#lastName', lastName)
      .type('#phoneNumber', phone)
      .click('#completeReservation')
      .wait('.reservation')
      .evaluate((url)=> {
        let comfirmation = document.getElementsByClassName('reservation-confirmation-number');

        if (comfirmation.length > 0) {
          return { success: true, message: comfirmation[0].innerHTML };
        } else{
          return { success: false, message: `\nThis restaurant needs a credit card to reserve.\n Please visit ${url} to claim the table.`};
        }

      }, url)
      .run(function(err, result) {
        callback(err, result);
      })

      .end()
  }
}

==> dorsia-0.3.7.tgz: package/src/opentable.js <==
"use strict";

const Nightmare = require('../node_modules/nightmare');
const moment = require("../node_modules/moment");
const Utility = require("./utility");
const async = require("../node_modules/async");
const chalk = require("../node_modules/chalk");

module.exports = {
  cityList: Utility.cityList,

  createRezObjs: (opentableIdArray, party, date, time) => {
    return Utility.createRezObjs(opentableIdArray, party, date, time);
  },

  queryEater: (city, debug, done) => {

    let url = Utility.getCityUrl(city);
    debug = (debug === true);

    new Nightmare({ show: debug, waitTimeout: 5000 })


    .goto(url)
    .inject('js', __dirname + '/../node_modules/jquery/dist/jquery.min.js')
    .wait('.l-map__points-content')

    .evaluate( function(city) {

      let restaurantInfoJSON = [];

      let restaurants = $('.m-map__item-card');

      for (let i = 0; i < restaurants.length; i++) {

        let $card = $(restaurants[i]);
        let name = $card.attr('data-name');
        let location = $card.attr('data-coordinates');
        let description = $($card.find('p')[0]).text();
        let webAndPhone = $card.find('div.m-map__item-website > div');
        let opentable = $card.find('.m-chorus-opentable-button');
        let isReservable = false;
        let phone = "no phone";
        let website = "no website provided";
        let opentableId = "";
        let reserveUrl = ""
        let reserveUrlMobile = ""
        let address = ""

        let address1 = $card.find('div.m-map__item-address > div:nth-child(1)');
        let address2 = $card.find('div.m-map__item-address > div:nth-child(2)');

        if (address1.length > 0) {
          address += address1[0].innerHTML.trim();
        }

        if (address2.length > 0) {
          address += '\n' + address2[0].innerHTML.trim();
        }

        if (webAndPhone.length > 0) {
          website = webAndPhone.find('a').attr('href');
        }

        if (webAndPhone.length > 1) {
          phone = webAndPhone[1].innerHTML.trim();
        }

        if (opentable.length > 0) {
          opentableId = opentable.attr('data-opentable-id');
          reserveUrl = `http://www.opentable.com/single.aspx?rid=${opentableId}`;
          reserveUrlMobile = `http://mobile.opentable.com/opentable/?restId=${opentableId}`;
          isReservable = true;
        }


        let restaurant = {
          name: name,
          isReservable: isReservable,
          opentableId: opentableId,
          reserveUrl: reserveUrl,
          reserveUrlMobile: reserveUrlMobile,
          location: location,
          description: description,
          address: address,
          phone: phone,
          website: website,
          city: city
        };

        restaurantInfoJSON.push(restaurant)

      }

      return restaurantInfoJSON

    }, city)

    .run(function (err, result) {
      if (err) {
        done(this,{message:"error pulling: " + city, city: city, success: false, data: result, error: err});
        console.log(chalk.red("error pulling: ") + city)
      } else {
        done(this,{message:"success pulling: " + city, city: city, success: true, data: result, error: err});
        console.log(chalk.blue("success pulling: ") + city)
      }
    })

    .end();
  },

  queryTables: (opts,debug,done) => {
    let url = `http://www.opentable.com/single.aspx?rid=${opts.restId}?p=${opts.party}&d=${opts.date}%20${opts.time}`
    debug = (debug === true);
    new Nightmare({ show: debug, waitTimeout: 5000 })

      .goto(url)
      .inject('js', __dirname + '/../node_modules/jquery/dist/jquery.min.js')
      .wait(2000)
      .wait('.dtp-picker-button')
      .click('.dtp-picker-button')
      .wait(2000)
      .wait('.dtp-result-text')
      .evaluate( function() {

        let times = $('#dtp-results > div > ul > li > a');
        let avalibleTimes = [];
        let name = $('h1.page-header-title')[0].innerHTML;

        for (let i = 0; i < times.length; i++) {

          let datetime = times[i].getAttribute('data-datetime');

          if (datetime) {
            avalibleTimes.push( datetime.split(' ')[1] );
          }

        }

        let reservation = {
          name: name,
          tables: avalibleTimes
        }

        return reservation;

      })

      .run(function (err, result) {
        if (err) {
          done(this,{message:"error pulling times for: " + opts.restId, success: false, optId: opts.restId, data: result, error: err});
          console.log(chalk.yellow("error polling: ") + opts.restId + chalk.red(" error: ") + err)
        } else {
          result['requestedDatetime'] = opts.time;
          done(this,{message:"success for: " + opts.restId, success: true, optId: opts.restId, data: result, error: err});
          console.log(chalk.blue("success polling: ") + opts.restId)
        }
      })
      .end()
  },

  openTables: function (rezObjs, debug, concurrentJobs, done) {
    var _this = this;
    var callbacks = [];
    async.eachLimit(rezObjs, concurrentJobs, function(rezObj,callback) {
      _this.queryTables(rezObj, debug, function(nm, result) {
        nm.end();
        callbacks.push(result);
        callback();
      });
    }, function(err) {
      console.log(err);
      console.log(callbacks);
      done(err, callbacks);
    })
  },

  eaterAll: function (debug,concurrentJobs,done) {
    var _this = this;
    var callbacks = [];
    let cites = Object.keys(Utility.cityList);
    async.eachLimit(cites, concurrentJobs, function(city,callback) {
      _this.queryEater(city, debug, function(nm,result) {
        nm.end();
        callbacks.push(result);
        callback();
      });
    }, function(err) {
      done(err, callbacks);
    })
  },

  reserveTable: function (opentableId, date, time, partySize, email, firstName, lastName, phone, callback) {
    const _this = this;
    //clean dates
    const dateString = Utility.getDateTimeString(date,time);
    let url = `http://www.opentable.com/single.aspx?rid=${opentableId}?p=${partySize}&d=${date}%20${time}`

    new Nightmare({ show: false, waitTimeout: 2000 })

      .goto(url)
      .inject('js', __dirname + '/../node_modules/jquery/dist/jquery.min.js')
      .click('.dtp-picker-button')
      .wait('.dtp-result-text')
      .wait(2000)
      .evaluate(function (dateString) {

        let times = $('#dtp-results > div > ul > li > a');
        let avalibleTimes = [];
        let timeIndex = null;

        for (let i = 0; i < times.length; i++) {

          let datetime = times[i].getAttribute('data-datetime');

          if (datetime && datetime === dateString) {
            timeIndex = i + 1;
          }

          if (datetime) {
            avalibleTimes.push( datetime.split(' ')[1] );
          }

        }

        const result = {
          times: avalibleTimes,
          index: timeIndex
        }

        return result

      }, dateString)

      .run( (err, result) => {

        if (err) {
          return console.log(err);
        } else {
          if (result.index) {
            _this.bookTable(opentableId, date, time, partySize,result.index, email, firstName, lastName, phone, (err, result) => {
                return callback(err,result);
            });

          } else {
            console.log();
            callback(null, { success: false, message:{ message: "No reservations availible at that time.", avalibleTimes: result.times } })
          }
        }
      })
      .end();
  },
  bookTable: function(opentableId, date, time, partySize, timeIndex, email, firstName, lastName, phone, callback) {

    const bookingSelector = `#dtp-results > div > ul > li:nth-child(${timeIndex}) > a`;
    const dateString = Utility.getDateTimeString(date,time);

    let url = `http://www.opentable.com/single.aspx?rid=${opentableId}?p=${partySize}&d=${date}%20${time}`

    new Nightmare({ show: false, waitTimeout: 2000})
      .goto(url)
      .inject('js', __dirname + '/../node_modules/jquery/dist/jquery.min.js')
      .click('.dtp-picker-button')
      .wait('.dtp-result-text')
      .click(bookingSelector)
      .type('#email', email)
      .type('#firstName', firstName)
      .type('#lastName', lastName)
      .type('#phoneNumber', phone)
      .click('#completeReservation')
      .wait('.reservation')
      .evaluate((url)=> {
        let comfirmation = document.getElementsByClassName('reservation-confirmation-number');

        if (comfirmation.length > 0) {
          return { success: true, message: comfirmation[0].innerHTML };
        } else{
          return { success: false, message: `\nThis restaurant needs a credit card to reserve.\n Please visit ${url} to claim the table.`};
        }

      }, url)
      .run(function(err, result) {
        callback(err, result);
      })

      .end()
  }
}
